/*
 * FileMatchingException.cs
 *
 * File Statistics
 * Version: 1.0
 *
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 *
 * Authors: WishingBone, TCSDEVELOPER
 */

using System;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// The exception that is thrown to encapsulate error from
    /// the <see cref="IFileMatcher"/> interface and its implementations
    /// to indicate a dependency error.
    /// </summary>
    ///
    /// <remarks>
    /// If a file operation fails, <see cref="System.IO.IOException"/> is used instead.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class FileMatchingException : FileStatisticsException
    {
        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="FileMatchingException"/> class
        /// with a specified error message.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        public FileMatchingException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="FileMatchingException"/> class
        /// with a specified error message
        /// and a reference to the inner exception
        /// that is the cause of this exception.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        /// <param name="cause">
        /// The exception that is the cause of the current exception.
        /// If the <paramref name="cause"/> parameter is not a null reference,
        /// the current exception is raised in a <b>catch</b> block
        /// that handles the inner exception.
        /// </param>
        public FileMatchingException(string message, Exception cause)
            : base(message, cause)
        {
        }
    }
}
