/*
 * InvalidArgumentException.cs
 *
 * File Statistics
 * Version: 1.0
 *
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 *
 * Authors: WishingBone, TCSDEVELOPER
 */

using System;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// The exception that is thrown from the <see cref="IArgumentHandler"/> interface
    /// to indicate the provided arguments are not valid.
    /// </summary>
    ///
    /// <remarks>
    /// Notice though validator can be returned from option proposal
    /// the receive method could implement more validation logic,
    /// or the logic needs to be performed on the combination of a few arguments
    /// rather than a single one.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class InvalidArgumentException : ConfigurationException
    {
        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="InvalidArgumentException"/> class
        /// with a specified error message.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        public InvalidArgumentException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="InvalidArgumentException"/> class
        /// with a specified error message
        /// and a reference to the inner exception
        /// that is the cause of this exception.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        /// <param name="cause">
        /// The exception that is the cause of the current exception.
        /// If the <paramref name="cause"/> parameter is not a null reference,
        /// the current exception is raised in a <b>catch</b> block
        /// that handles the inner exception.
        /// </param>
        public InvalidArgumentException(string message, Exception cause)
            : base(message, cause)
        {
        }
    }
 }
