/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/
using TopCoder.File.Statistics.Processor;
using TopCoder.File.Statistics.Matcher;
using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;
using System.Collections;
using TopCoder.Util.ConfigurationManager;
using TopCoder.File.Statistics.AccuracyTests;

namespace TopCoder.File.Statistics.AccuracyTests.Processor
{
    /// <summary>
    /// Accuracy tests for FileProcessorBase.
    /// </summary>
    [TestFixture]
    public class FileProcessorBaseAccuracyTest
    {       

        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            TestHelper.LoadConfig(TestHelper.PROCESSOR_CONFIG);
        }

        /// <summary>
        /// Tear down for each test.
        /// </summary>
        [TearDown]
        public void Teardown()
        {
            TestHelper.UnloadConfig(TestHelper.PROCESSOR_CONFIG);
        }

        /// <summary>
        /// Test that the alias and the file matcher are correctly loaded from configuration manager
        /// </summary>
        [Test]
        public void TestLoadingFromConfigManager()
        {
            IFileProcessor fp = new MockProcessor(TestHelper.FILE_STATISTICS_NAMESPACE, "processor1.");
            Assert.AreEqual("Text File", fp.Alias, "Bad alias retrieved for processor1");
            Assert.IsTrue(fp.FileMatcher is ExtensionMatcher, "Bad File matcher class for processor1");

            fp = new MockProcessor(TestHelper.FILE_STATISTICS_NAMESPACE, "processor2.");
            Assert.AreEqual("Type File", fp.Alias, "Bad alias retrieved for processor2");
            Assert.IsTrue(fp.FileMatcher is TypeNameMatcher, "Bad File matcher class for processor2");
        }


    }    
}