///
/// $(#)AnyFileMatcherTests.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
/// </summary>

using System;
using NUnit.Framework;

using TopCoder.File.Statistics.Matcher;

namespace TopCoder.File.Statistics.FailureTests.Matcher
{

	/// <summary>
    /// This test fixture contains the failure tests for <see cref="AnyFileMatcher"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class AnyFileMatcherTests {

	    /// <summary>
	    /// Checks whether the constructor AnyFileMatcher(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAnyFileMatcher1() {
            new AnyFileMatcher(null, "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor AnyFileMatcher(string, string) properly throws
	    /// ArgumentException for empty argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestAnyFileMatcher2() {
            new AnyFileMatcher("", "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor AnyFileMatcher(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAnyFileMatcher3() {
            new AnyFileMatcher("namespace", null);
	    }
	    
	    /// <summary>
	    /// Tests the match method with null argument. ArgumentNullException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestMatch() {
            new AnyFileMatcher().Match(null);
	    }
    }
}
